netapp_ontap.models.snapmirror_endpoint API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.snapmirror_endpoint`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class SnapmirrorEndpointSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the SnapmirrorEndpoint object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `cluster: Cluster GET POST PATCH`

    The cluster field of the snapmirror_endpoint.

  `consistency_group_volumes: List[SnapmirrorEndpointConsistencyGroupVolumes] GET POST`

    This property specifies the list of FlexVol volumes or LUNs of a Consistency Group. Optional on the ASA r2 platform. Mandatory for all other platforms.

  `ipspace: str POST`

    Optional property to specify the IPSpace of the SVM.

    Example: Default

  `luns: Lun GET POST PATCH`

    The luns field of the snapmirror_endpoint.

  `path: str GET POST PATCH`

    ONTAP FlexVol/FlexGroup - svm1:volume1 ONTAP SVM - svm1: ONTAP Consistency Group - svm1:/cg/cg_name ONTAP S3 - svm1:/bucket/bucket1 NON-ONTAP - objstore1:/objstore

    Example: svm1:volume1

  `svm: Svm GET`

    The svm field of the snapmirror_endpoint.